<?php

//
// Mark Claypool, WPI
// 2017
//

// Based on code by Jeroen van der Gun.
// https://tagpro.eu/?science

// Class to handle events for printing.
class PlayerEventHandler extends PlayerLogReader {

  protected function grabEvent($time, $newFlag, $powers, $team) {
    global $g_player, $g_events;
    global $g_grabs;
    if ($g_player->team)
      $g_grabs[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' grabs flag ' . $newFlag;
  }

  protected function captureEvent($time, $oldFlag, $powers, $team) {
    global $g_player, $g_events;
    global $g_captures;
    if ($g_player->team)
      $g_captures[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' captures flag ' . $oldFlag;
  }

  protected function powerupEvent($time, $flag, $powerUp, $newPowers, $team) {
    global $g_player, $g_events;
    global $g_powerups;
    if ($g_player->team)
      $g_powerups[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' powers up ' . $powerUp;
  }

  // Duplicate power ups are treated as power ups.
  protected function duplicatePowerupEvent($time, $flag, $powers, $team) {
    global $g_player, $g_events;
    global $g_powerups;
    if ($g_player->team)
      $g_powerups[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' extends power';
  }

  // Note, a return event implies a tag event.
  protected function returnEvent($time, $flag, $powers, $team) {
    global $g_player, $g_events;
    global $g_tags, $g_returns;
    if ($g_player->team) {
      $g_tags[$g_player->team]++;
      $g_returns[$g_player->team]++;
    }
    $g_events[$time][] = $g_player->name . ' returns';
  }

  protected function tagEvent($time, $flag, $powers, $team) {
    global $g_player, $g_events;
    global $g_tags;
    if ($g_player->team)
      $g_tags[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' tags';
  }

  // Note, a drop event implies a pop event.
  protected function dropEvent($time, $oldFlag, $powers, $team) {
    global $g_player, $g_events;
    global $g_drops, $g_pops;
    if ($g_player->team) {
      $g_drops[$g_player->team]++;
      $g_pops[$g_player->team]++;
    }
    $g_events[$time][] = $g_player->name . ' drops flag ' . $oldFlag;
  }

  protected function popEvent($time, $powers, $team) {
    global $g_player, $g_events;
    global $g_pops;
    if ($g_player->team)
      $g_pops[$g_player->team]++;
    $g_events[$time][] = $g_player->name . ' pops';
  }

  public function __construct() {
    global $g_match, $g_player, $g_events;
    global $g_player_score;
    global $g_player_degree;

    // Note, if player joined after start, team is 0 so don't tally.
    if ($g_player->team) {
      $g_player_score[$g_player->team] += $g_player->score;
      $g_player_degree[$g_player->team] += $g_player->degree;
    }

    if ($g_player->team)
      $g_events[0][] = $g_player->name . ' starts in team ' . $g_player->team;
    parent::__construct(base64_decode($g_player->events),
                        $g_player->team, $g_match->duration);
   }
}
?>
