#!/usr/bin/php
<?php

//
// Mark Claypool, WPI
// 2017
//

// Parse TagPro bulk match data, providing map statistics.
// version 1.0
// 
// Works with files downloaded using "Download Matches" from:
//   https://tagpro.eu/?science
// 
// Requires download of bulk match data using "Download maps" from:
//   https://tagpro.eu/?science
// in a file named "bulkmaps.json".

// Based on code by Jeroen van der Gun.
// https://tagpro.eu/?science

require './LogReader.php';

// Make sure have at one command line arg.
if ($argc < 2) {
  printf("Usage: php %s {filename} [filename] ...\n", $argv[0]);
  printf("  Download bulk map/match data at https://tagpro.eu/?science\n");
  exit(0);
}

# If on Windows, use the below to support wildcard expansion from the
# command line.
$filenames = array();
array_push($filenames, $argv[0]);
$i = 1;
while ($i < $argc) {
  if (strpos($argv[$i], '*') !== false) {
    array_push($filenames, glob($argv[$i]));
  } else
    array_push($filenames, $argv[$i]);
  $i++;    
}
$argc = $i;
$argv = $filenames;

// Make sure bulkmaps.json exists.
if (!file_exists("bulkmaps.json")) {
  printf("Unable to find required file 'bulkmaps.json'!\n");
  printf("  Download bulk map data at https://tagpro.eu/?science\n");
  printf("Exiting.\n");
  exit(0);
}

// Go through all files.
$map_handler = null;
for ($i=1; $i<$argc; $i++) {

  $filename = $argv[$i];

  // Make sure match file exists.
  if (!file_exists($filename)) {
    printf("Unable to open file '%s'!\n", $filename);
    printf("  Download bulk match data at https://tagpro.eu/?science\n");
    printf("Exiting.\n");
    exit(0);
  }

  // Read in maps into an associative array.
  $all_maps = json_decode(file_get_contents("bulkmaps.json"), true);

  // Read in match.
  $all_matches = json_decode(file_get_contents($filename), true);
  $keys = array_keys($all_matches);
     
  // Go through all matches.
  $map_handler = null;
  foreach ($keys as $i) {
    $this_match = $all_matches[$i];
    
    // If this is a bulk download, it will have a map id.
    // Replace it with map data.
    if (array_key_exists('mapId', $this_match)) {
      $map_id = $this_match['mapId'];
      $map = $all_maps[$map_id];
      unset($this_match['mapId']);
      $this_match['map'] = $map;
    }
    //$match = json_decode(json_encode($this_match));
    $all_matches[$i] = $this_match;

  }

  // Print out.
  print(json_encode($all_matches));
}

exit();

?>
