#!/usr/bin/php
<?php

//
// Mark Claypool, WPI
// 2017
//

// Parse TagPro match data, providing statistics.
// version 1.1
// 
// Works with TagProg game files saved with:
//   https://tagpro.eu/userscript.user.js

// Based on code by Jeroen van der Gun.
// https://tagpro.eu/?science

// Needed imports.
require './LogReader.php';
require './MapEventHandler.php';
require './PlayerEventHandler.php';

$MAX_NAME_LEN = 10;  // Restrict super-long names.

// Make sure have at least one command line arg.
if ($argc < 2) {
  printf("Usage: php %s {filename} [filename] ...\n", $argv[0]);
  exit(0);
}

# Check if Windows.
if (stripos(PHP_OS, 'WIN') !== false) {

  # Use the below to support wildcard expansion from the
  # command line.
  $filenames = array();
  array_push($filenames, $argv[0]);
  $i = 1;
  while ($i < $argc) {
    if (strpos($argv[$i], '*') !== false) {
      $g = glob($argv[$i]);  // First element Array (Windows only).
      for ($j = 1; $j<sizeof($g); $j++)
        array_push($filenames, $g[$j]);
    } else
      array_push($filenames, $argv[$i]);
    $i++;    
  }
  $argc = sizeof($filenames);
  $argv = $filenames;
}

// Print header.
print("g_date, ");
print("m_name, ");
print("m_author, ");
print("m_area, ");
print("m_walls, ");
print("m_flags, ");
print("m_speeds, ");
print("m_bttns, ");
print("m_pwrups, ");
print("m_spikes, ");
print("m_bombs, ");
print("m_gates, ");
print("m_tlimit, ");
print("g_duration, ");
print("g_grabs_red, ");
print("g_grabs_blue, ");
print("g_captures_red, ");
print("g_captures_blue, ");
print("g_powerups_red, ");
print("g_powerups_blue, ");
print("g_pops_red, ");
print("g_pops_blue, ");
print("g_drops_red, ");
print("g_drops_blue, ");
print("g_tags_red, ");
print("g_tags_blue, ");
print("g_returns_red, ");
print("g_returns_blue, ");
print("g_player_degree_red, ");
print("g_player_degree_blue, ");
print("g_player_score_red, ");
print("g_player_score_blue, ");
print("g_team_score_red, ");
print("g_team_score_blue, ");
print("\n");

// Go through all files.
$map_handler = null;
for ($i=1; $i<$argc; $i++) {

  $filename = $argv[$i];

  if (!file_exists($filename)) {
    printf("Unable to open file '%s'!\n", $filename);
    continue;
  }

  // Decode file.
  $decoded_string = json_decode(file_get_contents($filename));
  $decoded_array = json_decode(file_get_contents($filename), true);

  // See if more than one match in file.
  if (empty($decoded_array[1]))
    $is_mult_matches = false;
  else
    $is_mult_matches = true;

  if ($is_mult_matches)
    reset($decoded_array);
  $done = false;
  while (!$done) {

    if ($is_mult_matches) {
      $g_match = json_decode(json_encode(current($decoded_array)));
      $match = current($decoded_array);
    } else {
      $g_match = $decoded_string;
      $match = $decoded_array;
    }    

    // Global variables to record map stats.
    $g_wall_tile = 0;
    $g_flag_tile = 0;
    $g_speed_tile = 0;
    $g_button_tile = 0;
    $g_powerup_tile = 0;
    $g_spike_tile = 0;
    $g_bomb_tile = 0;
    $g_gate_tile = 0;
    $g_area = 0;

    // Read in match.
    $map = $match['map'];
    $map_name = substr($map['name'], 0, $MAX_NAME_LEN);
    $map_author = substr($map['author'], 0, $MAX_NAME_LEN);
    $duration = $match['duration'];
    $tlimit = $match['timeLimit'];
    $date = $match['date'];
    
    // Create MapEventHandler object to parse map.
    if ($map_handler != null) 
        unset($map_handler);
    $map_handler = new MapEventHandler();

    // Print out map stats.
    print("$date, ");
    print("$map_name, ");
    print("$map_author, ");
    print("$g_area, ");
    print("$g_wall_tile, ");
    print("$g_flag_tile, ");
    print("$g_speed_tile, ");
    print("$g_button_tile, ");
    print("$g_powerup_tile, ");
    print("$g_spike_tile, ");
    print("$g_bomb_tile, ");
    print("$g_gate_tile, ");
    print("$tlimit, ");
    print("$duration, ");
    
    // Global variables to record player stats.
    $g_grabs[1] = 0;
    $g_grabs[2] = 0;
    $g_captures[1] = 0;
    $g_captures[2] = 0;
    $g_powerups[1] = 0;
    $g_powerups[2] = 0;
    $g_pops[1] = 0;
    $g_pops[2] = 0;
    $g_drops[1] = 0;
    $g_drops[2] = 0;
    $g_tags[1] = 0;
    $g_tags[2] = 0;
    $g_returns[1] = 0;
    $g_returns[2] = 0;
    $g_player_degree[1] = 0;
    $g_player_degree[2] = 0;
    $g_player_score[1] = 0;
    $g_player_score[2] = 0;

    // Tally up player attributes.
    $g_events = array();
    foreach ($g_match->players as $g_player)
      new PlayerEventHandler();
    
    // Record game score.
    foreach ($g_match->teams as $team) {
      if ($team -> name == "Red") 
        $score[1] = $team -> score;
      else
        $score[2] = $team -> score;
    }
    
    print("$g_grabs[1], ");
    print("$g_grabs[2], ");
    print("$g_captures[1], ");
    print("$g_captures[2], ");
    print("$g_powerups[1], ");
    print("$g_powerups[2], ");
    print("$g_pops[1], ");
    print("$g_pops[2], ");
    print("$g_drops[1], ");
    print("$g_drops[2], ");
    print("$g_tags[1], ");
    print("$g_tags[2], ");
    print("$g_returns[1], ");
    print("$g_returns[2], ");
    print("$g_player_degree[1], ");
    print("$g_player_degree[2], ");
    print("$g_player_score[1], ");
    print("$g_player_score[2], ");
    print("$score[1], ");
    print("$score[2], ");
    print("\n");

    // Next match, if appropriate.
    if ($is_mult_matches) {
      next($decoded_array);
      if (!current($decoded_array))
        $done = true;
    } else {
      $done = true;
    }
  }
  
}

exit();

// Format time string.
function timeFormat($time) {
    return floor($time/3600).':'.str_pad(floor($time%3600/60),2,'0',STR_PAD_LEFT).'.'.str_pad(round($time%60/0.6),2,'0',STR_PAD_LEFT);
}
  
?>
