#!/usr/bin/php
<?php

//
// Mark Claypool, WPI
// 2017
//

// Parse TagPro match data, providing statistics.
// version 1.1
// 
// Works with TagProg game files saved with:
//   https://tagpro.eu/userscript.user.js

// Based on code by Jeroen van der Gun.
// https://tagpro.eu/?science

// Needed imports.
require './LogReader.php';
require './SplatEventHandler.php';

////////////////////////////////////
// Needed just to calculate map height.
class MapHeightHandler extends MapLogReader {
  protected function heightEvent($newY) {
    global $g_map_height;
    $g_map_height = $newY + 1;
  }

  public function __construct() {
    global $g_match;
    parent::__construct(base64_decode($g_match->map->tiles),
                                      $g_match->map->width);
  }
}
////////////////////////////////////

$MAX_NAME_LEN = 10;  // Restrict super-long names.

// Make sure have at least one command line arg.
if ($argc < 2) {
  printf("Usage: php %s {filename} [filename] ...\n", $argv[0]);
  exit(0);
}

# Check if Windows.
if (stripos(PHP_OS, 'WIN') !== false) {

  # Use the below to support wildcard expansion from the
  # command line.
  $filenames = array();
  array_push($filenames, $argv[0]);
  $i = 1;
  while ($i < $argc) {
    if (strpos($argv[$i], '*') !== false) {
      $g = glob($argv[$i]);  // First element Array (Windows only).
      for ($j = 1; $j<sizeof($g); $j++)
        array_push($filenames, $g[$j]);
    } else
      array_push($filenames, $argv[$i]);
    $i++;    
  }
  $argc = sizeof($filenames);
  $argv = $filenames;
}

// Go through all files.
$splat_handler = null;
$map_handler = null;
for ($i=1; $i<$argc; $i++) {

  $filename = $argv[$i];

  if (!file_exists($filename)) {
    printf("Unable to open file '%s'!\n", $filename);
    continue;
  }

  // Decode file.
  $decoded_string = json_decode(file_get_contents($filename));
  $decoded_array = json_decode(file_get_contents($filename), true);

  // See if more than one match in file.
  if (empty($decoded_array[1]))
    $is_mult_matches = false;
  else
    $is_mult_matches = true;

  if ($is_mult_matches)
    reset($decoded_array);
  $done = false;
  while (!$done) {

    if ($is_mult_matches) {
      $g_match = json_decode(json_encode(current($decoded_array)));
      $match = current($decoded_array);
    } else {
      $g_match = $decoded_string;
      $match = $decoded_array;
    }
    
    // Create MapHeightHandler object to 
    // compute map height.
    if ($map_handler != null)
      unset($map_handler);
    $g_map_height = 0;
    $map_handler = new MapHeightHandler();
    
    // Header information.
    $date = $match['date'];
    $name = $match['map']['name'];
    print("\nDate: $date,\n");
    print("Map name: $name,\n\n");

    // Record splats.
    foreach ($g_match->teams as $g_team) {
      if ($splat_handler != null) 
        unset($splat_handler);
      $splat_handler = new SplatEventHandler();
    }

    // Next match, if appropriate.
    if ($is_mult_matches) {
      next($decoded_array);
      if (!current($decoded_array))
        $done = true;
    } else {
      $done = true;
    }
  }
  
}

exit();

?>
